@@ -1,7 +1,7 @@
 package App::orgsel;
 
-our $DATE = '2016-08-30'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2016-09-01'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,7 +45,8 @@ sub orgsel {
         {class_prefixes=>["Org::Element"]}, $expr, $doc);
 
     # skip root node itself
-    @matches = grep { refaddr($_) ne refaddr($doc) } @matches;
+    @matches = grep { refaddr($_) ne refaddr($doc) } @matches
+        unless @matches <= 1;
 
     App::CSelUtils::do_actions_on_nodes(
         nodes   => \@matches,
@@ -68,7 +69,7 @@ App::orgsel - Select Org document elements using CSel (CSS-selector-like) syntax
 
 =head1 VERSION
 
-This document describes version 0.004 of App::orgsel (from Perl distribution App-orgsel), released on 2016-08-30.
+This document describes version 0.005 of App::orgsel (from Perl distribution App-orgsel), released on 2016-09-01.
 
 =head1 SYNOPSIS
 
